@@ -120,7 +120,10 @@ def main():
             elif filterenv.startswith("default"):
                 util.compile_expression = util.compile_expression_defaultdict
 
-        # format string separator
+        # format string options
+        if not config.get((), "format-operator-dot", True):
+            from . import formatter
+            formatter._attrgetter = formatter.operator.attrgetter
         if separator := config.get((), "format-separator"):
             from . import formatter
             formatter._SEPARATOR = separator
@@ -284,14 +287,14 @@ def main():
 
             # unsupported file logging handler
             if handler := output.setup_logging_handler(
-                    "unsupportedfile", fmt="{message}"):
+                    "unsupportedfile", fmt="{message}", defer=True):
                 ulog = job.Job.ulog = logging.getLogger("unsupported")
                 ulog.addHandler(handler)
                 ulog.propagate = False
 
             # error file logging handler
             if handler := output.setup_logging_handler(
-                    "errorfile", fmt="{message}", mode="a"):
+                    "errorfile", fmt="{message}", mode="a", defer=True):
                 elog = input_manager.err = logging.getLogger("errorfile")
                 elog.addHandler(handler)
                 elog.propagate = False
