@@ -193,11 +193,13 @@ CATEGORY_MAP = {
     "thebarchive"    : "The /b/ Archive",
     "thecollection"  : "The /co/llection",
     "thecollectionS" : "The /co/llection",
+    "thefap"         : "TheFap",
     "thehentaiworld" : "The Hentai World",
     "tiktok"         : "TikTok",
     "tmohentai"      : "TMOHentai",
     "tumblrgallery"  : "TumblrGallery",
     "turboimagehost" : "TurboImageHost.com",
+    "turbovid"       : "turbovid.cr",
     "vanillarock"    : "もえぴりあ",
     "vidyart2"       : "/v/idyart2",
     "vidyapics"      : "Vidya Booru",
@@ -266,6 +268,9 @@ SUBCATEGORY_MAP = {
     "boosty": {
         "feed": "Subscriptions Feed",
     },
+    "booth": {
+        "category": "Item Categories",
+    },
     "cfake": {
         "created": "Created",
     },
@@ -465,6 +470,11 @@ SUBCATEGORY_MAP = {
     "wikimedia": {
         "article": ["Articles", "Categories", "Files"],
     },
+    "xenforo": {
+        "media-user": "User Media",
+        "media-item": "Media Files",
+        "media-category": "Media Categories",
+    },
 }
 
 BASE_MAP = {
@@ -698,6 +708,11 @@ def build_extractor_list():
     default["wikifeetx"] = default["wikifeet"]
     domains["wikifeetx"] = "https://www.wikifeetx.com/"
 
+    # turbovid
+    default["turbovid"] = default["saint"]
+    domains["turbovid"] = "https://turbovid.cr/"
+    domains["saint"] = "https://saint2.su/"
+
     # imgdrive / imgtaxi / imgwallet
     base = categories["imagehost"]
     base["imgtaxi"] = base["imgdrive"]
