@@ -190,6 +190,42 @@ __tests__ = (
     ],
 },
 
+{
+    "#url"     : "https://etlabsotwe.fanbox.cc/posts/11070192",
+    "#comment" : "(potentially?) missing 'publishedDatetime' (#8711)",
+    "#class"   : fanbox.FanboxPostExtractor,
+    "#results" : "https://pixiv.pximg.net/fanbox/public/images/post/11070192/cover/MGoWoTnJphuJSkD3owo3r7wG.jpeg",
+
+    "archives"       : (),
+    "creatorId"      : "etlabsotwe",
+    "date"           : "dt:2025-12-15 11:31:50",
+    "excerpt"        : "",
+    "extension"      : "jpeg",
+    "feeRequired"    : 200,
+    "fileUrl"        : "https://pixiv.pximg.net/fanbox/public/images/post/11070192/cover/MGoWoTnJphuJSkD3owo3r7wG.jpeg",
+    "filename"       : "MGoWoTnJphuJSkD3owo3r7wG",
+    "hasAdultContent": True,
+    "id"             : "11070192",
+    "imageForShare"  : "https://pixiv.pximg.net/c/1200x630_90_a2_g5/fanbox/public/images/post/11070192/cover/MGoWoTnJphuJSkD3owo3r7wG.jpeg",
+    "isCommentingRestricted": False,
+    "isCoverImage"   : True,
+    "isLiked"        : False,
+    "isPinned"       : False,
+    "isRestricted"   : True,
+    "likeCount"      : int,
+    "num"            : 0,
+    "publishedDatetime": "2025-12-15T20:31:50+09:00",
+    "tags"           : [],
+    "text"           : None,
+    "title"          : "Sketches 2025-12-15",
+    "type"           : "article",
+    "updatedDatetime": "iso:dt",
+    "user"           : {
+        "name"   : "ET",
+        "userId" : "74814193",
+    },
+},
+
 {
     "#url"     : "https://fanbox.cc/",
     "#category": ("", "fanbox", "home"),
