@@ -22,25 +22,24 @@ __tests__ = (
         "author"    : "Zebrabobinn",
         "author_id" : "171827",
         "author_url": "https://simpcity.cr/members/zebrabobinn.171827/",
+        "author_slug": "zebrabobinn",
         "count"     : 1,
         "date"      : "dt:2023-03-08 12:59:10",
         "id"        : "1753131",
-        "content"   : """\
-<div class="bbWrapper"><a href="https://jpg6.su/img/coWRwo" target="_blank" class="link link--external" rel="noopener"><img src="https://simp6.jpg6.su/images/FqsNcNCaIAITBEL.md.jpg" data-url="https://simp6.jpg6.su/images/FqsNcNCaIAITBEL.md.jpg" class="bbImage " loading="lazy"
-\t\talt="FqsNcNCaIAITBEL.md.jpg" title="FqsNcNCaIAITBEL.md.jpg" style="" width="" height="" /></a></div>\
-""",
+        "content"   : str,
     },
     "thread": {
         "author"    : "eula",
         "author_id" : "54987",
         "author_url": "https://simpcity.cr/members/eula.54987/",
+        "author_slug": "eula",
         "date"      : "dt:2022-03-11 17:15:59",
         "id"        : "10731",
         "posts"     : range(320, 500),
         "section"   : "Asians",
         "title"     : "Ririkana | RR_loveit",
         "url"       : "https://simpcity.cr/threads/ririkana-rr_loveit.10731/",
-        "views"     : range(790_000, 900_000),
+        "views"     : range(900_000, 2_000_000),
         "tags"      : [
             "asian",
             "big ass",
@@ -69,10 +68,10 @@ __tests__ = (
     "#auth"    : True,
     "#results" : (
         "https://jpg6.su/img/NNFssUg",
-        "https://saint2.cr/embed/nPy1kG3w55V",
-        "https://saint2.cr/embed/c0KhPjU4-F3",
-        "https://saint2.cr/embed/sZWnVZ_mQsV",
-        "https://saint2.cr/embed/MEBiLx6DETQ",
+        "https://turbovid.cr/embed/nPy1kG3w55V",
+        "https://turbovid.cr/embed/c0KhPjU4-F3",
+        "https://turbovid.cr/embed/sZWnVZ_mQsV",
+        "https://turbovid.cr/embed/MEBiLx6DETQ",
     ),
 },
 
@@ -104,6 +103,7 @@ __tests__ = (
         "author"    : "Hexorium",
         "author_id" : "3715883",
         "author_url": "https://simpcity.cr/members/hexorium.3715883/",
+        "author_slug": "hexorium",
         "count"     : 6,
         "date"      : "dt:2024-12-15 21:37:05",
         "id"        : "12065490",
@@ -112,6 +112,7 @@ __tests__ = (
         "author"    : "Deleted member 166159",
         "author_id" : "166159",
         "author_url": "",
+        "author_slug": "deleted-member",
         "date"      : "dt:2022-04-05 14:48:14",
         "id"        : "36572",
         "section"   : "Premium Asians",
@@ -214,12 +215,37 @@ __tests__ = (
     "#results" : "https://redgifs.com/ifr/unusedsubmissivemullet",
 },
 
+{
+    "#url"     : "https://simpcity.cr/threads/snowball7766.1490941/post-38256229",
+    "#comment" : "bbImageWrapper blocks (#8868)",
+    "#category": ("xenforo", "simpcity", "post"),
+    "#class"   : xenforo.XenforoPostExtractor,
+    "#auth"    : True,
+    "#results" : (
+        "https://www.instagram.com/snowball7766/",
+        "https://www.threads.com/@snowball7766",
+        "https://www.facebook.com/ball.snow.7773#",
+        "https://simp6.selti-delivery.ru/images3/82489639_3012191048813651_5086244093198073856_o94d88f27678869a9.jpg",
+        "https://simp6.selti-delivery.ru/images3/81822451_3012190595480363_7751669220496113664_od8fd937464a00f73.jpg",
+        "https://simp6.selti-delivery.ru/images3/81459259_3012190838813672_781773786918682624_o880c1a4f0aa402c2.jpg",
+        "https://simp6.selti-delivery.ru/images3/81936276_3012190545480368_1653404646221283328_oab69119416354f10.jpg",
+        "https://simp6.selti-delivery.ru/images3/82375666_3012191015480321_6208103187434438656_of41cd9f33c2f5d2b.jpg",
+        "https://simp6.selti-delivery.ru/images3/82453137_3012190802147009_1828394700625674240_o9f4ee63fffbfc3de.jpg",
+        "https://simp6.selti-delivery.ru/images3/82710873_3012190752147014_2275240512531202048_o31a8e0ff56b05fa6.jpg",
+        "https://simp6.selti-delivery.ru/images3/82919150_3012190608813695_447262977784020992_o8105006061c5fd32.jpg",
+        "https://simp6.selti-delivery.ru/images3/49013049333_eed56c4a94_ob0809a5e8b720026.jpg",
+        "https://simp6.selti-delivery.ru/images3/49013783762_6143932191_o76c074c41effc49f.jpg",
+        "https://simp6.selti-delivery.ru/images3/49013792187_8a9f1066e6_o9359dcb86e42dba6.jpg",
+        "https://simp6.selti-delivery.ru/images3/52044873_2357680964251830_3177806178725920768_n3f60e7febf7ed056.jpg",
+    ),
+},
+
 {
     "#url"     : "https://simpcity.cr/threads/alua-tatakai.89490/",
     "#category": ("xenforo", "simpcity", "thread"),
     "#class"   : xenforo.XenforoThreadExtractor,
     "#auth"    : True,
-    "#pattern" : r"https://(jpg6\.su/img/\w+|bunkr\.\w+/[fiv]/\w+|pixeldrain.com/l/\w+|alua.com/tatakai)|saint2.cr/embed",
+    "#pattern" : r"https://(jpg6\.su/img/\w+|bunkr\.\w+/[fiv]/\w+|pixeldrain.com/l/\w+|alua.com/tatakai)|turbovid.cr/embed",
     "#count"   : range(100, 300),
 
     "count" : int,
