@@ -802,9 +802,14 @@ The Washington Post writes, "Three weeks after the toxic train derailment in Ohi
     "#class"   : twitter.TwitterHomeExtractor,
 },
 
+{
+    "#url"     : "https://x.com/notifications",
+    "#class"   : twitter.TwitterNotificationsExtractor,
+},
+
 {
     "#url"     : "https://x.com/i/timeline",
-    "#class"   : twitter.TwitterHomeExtractor,
+    "#class"   : twitter.TwitterNotificationsExtractor,
 },
 
 )
